These JSON files were taken from live testing, rather than from SmartThings documentation.
Confidential information (device ids, tokens, etc.) are partially masked, but retain the
same realistic length and format.